==> node-itk-0.1.2.tgz: package/example/readwrite.js <==
var node_itk = require('node-itk');

var image = new node_itk.NodeImage('uchar',2);

console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());

image.Read('uchar',2, 'Desert.jpg');
image.Write('uc2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('char',2, 'Desert.jpg');
image.Write('c2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('short',2, 'Desert.jpg');
image.Write('s2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('ushort',2, 'Desert.jpg');
image.Write('us2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('long',2, 'Desert.jpg');
image.Write('l2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('ulong',2, 'Desert.jpg');
image.Write('ul2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('int',2, 'Desert.jpg');
image.Write('i2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('uint',2, 'Desert.jpg');
image.Write('ui2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('float',2, 'Desert.jpg');
image.Write('f2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('double',2, 'Desert.jpg');
image.Write('d2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());

==> node-itk-0.1.3.tgz: package/example/readwrite.js <==
var node_itk = require('node-itk');

var image = new node_itk.NodeImage('uchar',2);

console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());

image.Read('uchar',2, 'Desert.jpg');
image.Write('uc2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('char',2, 'Desert.jpg');
image.Write('c2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('short',2, 'Desert.jpg');
image.Write('s2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('ushort',2, 'Desert.jpg');
image.Write('us2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('long',2, 'Desert.jpg');
image.Write('l2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('ulong',2, 'Desert.jpg');
image.Write('ul2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('int',2, 'Desert.jpg');
image.Write('i2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('uint',2, 'Desert.jpg');
image.Write('ui2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('float',2, './Data/Desert.jpg');
image.Write('f2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
image.Read('double',2, './Data/Desert.jpg');
image.Write('d2.jpg');
console.log('pixel:'+image.GetPixelType());
console.log(image.GetDimension());
